@@ -4,7 +4,7 @@ module FaradayMiddleware
   # Public: Restore marshalled Ruby objects in response bodies.
   class ParseMarshal < ResponseMiddleware
     define_parser do |body|
-      ::Marshal.load body unless body.empty?
+      ::Marshal.load(body) unless body.empty?
     end
   end
 end
