@@ -17,6 +17,7 @@ if ENV['COVERAGE']
 end
 
 require 'rspec'
+require 'webmock/rspec'
 require 'faraday'
 
 module EnvCompatibility
@@ -43,9 +44,11 @@ module ResponseMiddlewareExampleGroup
   def process(body, content_type = nil, options = {})
     env = {
       :body => body, :request => options,
+      :request_headers => Faraday::Utils::Headers.new,
       :response_headers => Faraday::Utils::Headers.new(headers)
     }
     env[:response_headers]['content-type'] = content_type if content_type
+    yield(env) if block_given?
     middleware.call(faraday_env(env))
   end
 end
